@@ -275,8 +275,7 @@ static QItemSelection getRootRanges(const QItemSelection &_selection)
     }
 
     it = selection.begin();
-    const QList<QItemSelectionRange>::iterator end = selection.end();
-    while (it != end) {
+    while (it != selection.end()) {
         const QItemSelectionRange range = *it;
         it = selection.erase(it);
 
@@ -430,7 +429,7 @@ public:
     /**
       Keeping Persistent indexes from this model in this model breaks in certain situations
       such as after source insert, but before calling endInsertRows in this model. In such a state,
-      the persistent indexes are not updated, but the methods assume they are already uptodate.
+      the persistent indexes are not updated, but the methods assume they are already up-to-date.
 
       Instead of using persistentindexes for proxy indexes in m_mappedParents, we maintain them ourselves with this method.
 
@@ -754,7 +753,7 @@ void KSelectionProxyModelPrivate::sourceLayoutAboutToBeChanged()
     Q_EMIT q->layoutAboutToBeChanged();
 
     QItemSelection selection;
-    for (const QModelIndex &rootIndex : qAsConst(m_rootIndexList)) {
+    for (const QModelIndex &rootIndex : std::as_const(m_rootIndexList)) {
         // This will be optimized later.
         Q_EMIT q->rootIndexAboutToBeRemoved(rootIndex, {});
         selection.append(QItemSelectionRange(rootIndex, rootIndex));
@@ -765,7 +764,7 @@ void KSelectionProxyModelPrivate::sourceLayoutAboutToBeChanged()
 
     QPersistentModelIndex srcPersistentIndex;
     const auto lst = q->persistentIndexList();
-    for (const QPersistentModelIndex &proxyPersistentIndex : lst) {
+    for (const QModelIndex &proxyPersistentIndex : lst) {
         m_proxyIndexes << proxyPersistentIndex;
         Q_ASSERT(proxyPersistentIndex.isValid());
         srcPersistentIndex = q->mapToSource(proxyPersistentIndex);
@@ -1069,7 +1068,7 @@ void KSelectionProxyModelPrivate::sourceRowsInserted(const QModelIndex &parent,
     m_rowsInserted = false;
     endInsertRows(parent, start, end);
     q->endInsertRows();
-    for (const PendingSelectionChange &pendingChange : qAsConst(m_pendingSelectionChanges)) {
+    for (const PendingSelectionChange &pendingChange : std::as_const(m_pendingSelectionChanges)) {
         selectionChanged(pendingChange.selected, pendingChange.deselected);
     }
     m_pendingSelectionChanges.clear();
@@ -1639,32 +1638,32 @@ void KSelectionProxyModelPrivate::removeParentMappings(const QModelIndex &parent
 
     Q_ASSERT(parent.isValid() ? parent.model() == q : true);
 
-    SourceProxyIndexMapping::right_iterator it = m_mappedParents.rightBegin();
-    SourceProxyIndexMapping::right_iterator endIt = m_mappedParents.rightEnd();
-
-    const bool flatList = isFlat();
-
-    while (it != endIt) {
+    // collect all removals first, as executing them recursively will invalidate our iterators
+    struct RemovalInfo {
+        QPersistentModelIndex idx;
+        QModelIndex sourceIdx;
+    };
+    std::vector<RemovalInfo> removals;
+    removals.reserve(end - start + 1);
+    for (auto it = m_mappedParents.rightBegin(); it != m_mappedParents.rightEnd(); ++it) {
         if (it.key().row() >= start && it.key().row() <= end) {
             const QModelIndex sourceParent = it.value();
             const QModelIndex proxyGrandParent = mapParentFromSource(sourceParent.parent());
             if (proxyGrandParent == parent) {
-                if (!flatList)
-                // Due to recursive calls, we could have several iterators on the container
-                // when erase is called. That's safe according to the QHash::iterator docs though.
-                {
-                    removeParentMappings(it.key(), 0, q->sourceModel()->rowCount(it.value()) - 1);
-                }
-
-                m_parentIds.removeRight(it.key());
-                it = m_mappedParents.eraseRight(it);
-            } else {
-                ++it;
+                removals.push_back({it.key(), it.value()});
             }
-        } else {
-            ++it;
         }
     }
+
+    // execute the removals
+    const bool flatList = isFlat();
+    for (const auto &r : removals) {
+        if (!flatList) {
+            removeParentMappings(r.idx, 0, q->sourceModel()->rowCount(r.sourceIdx) - 1);
+        }
+        m_parentIds.removeRight(r.idx);
+        m_mappedParents.removeRight(r.idx);
+    }
 }
 
 QModelIndex KSelectionProxyModelPrivate::mapTopLevelToSource(int row, int column) const
