@@ -6,14 +6,17 @@
 
 #include "plugin.h"
 
-#include <QQmlContext>
 #include <QDebug>
+#include <QQmlContext>
 
+#include "ksortfilterproxymodel.h"
+#include <KColumnHeadersModel>
 #include <KDescendantsProxyModel>
 #include <KNumberModel>
-#include <KColumnHeadersModel>
-#include "ksortfilterproxymodel.h"
+#if KITEMMODELS_BUILD_DEPRECATED_SINCE(5, 80)
 #include "kconcatenaterowsproxymodel_qml.h"
+#endif
+#include "kdescendantsproxymodel_qml.h"
 
 void Plugin::initializeEngine(QQmlEngine *engine, const char *uri)
 {
@@ -23,13 +26,11 @@ void Plugin::initializeEngine(QQmlEngine *engine, const char *uri)
 
 void Plugin::registerTypes(const char *uri)
 {
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
     qmlRegisterAnonymousType<QAbstractItemModel>(uri, 1);
-#else
-    qmlRegisterType<QAbstractItemModel>();
+#if KITEMMODELS_BUILD_DEPRECATED_SINCE(5, 80)
+    qmlRegisterExtendedType<KConcatenateRowsProxyModel, KConcatenateRowsProxyModelQml>(uri, 1, 0, "KConcatenateRowsProxyModel");
 #endif
-    qmlRegisterExtendedType<KConcatenateRowsProxyModel,KConcatenateRowsProxyModelQml>(uri, 1, 0, "KConcatenateRowsProxyModel");
-    qmlRegisterType<KDescendantsProxyModel>(uri, 1, 0, "KDescendantsProxyModel");
+    qmlRegisterType<KDescendantsProxyModelQml>(uri, 1, 0, "KDescendantsProxyModel");
     qmlRegisterType<KNumberModel>(uri, 1, 0, "KNumberModel");
     qmlRegisterType<KColumnHeadersModel>(uri, 1, 0, "KColumnHeadersModel");
     qmlRegisterType<KSortFilterProxyModel>(uri, 1, 0, "KSortFilterProxyModel");
